using FitConnect.Models.Api.Metadata;

namespace FitConnect.Builder;

public class AuthenticationInformationBuilder : IAuthenticationInformationBuilderWithContent,
    IAuthenticationInformationBuilderWithType, IAuthenticationInformationBuilderWithVersion {
    public string? Content { get; set; }
    public AuthenticationInformationType? Type { get; set; }
    public string? Version { get; set; }

    public IAuthenticationInformationBuilderWithContent WithContent(string value) {
        this.Content = value;
        return this;
    }

    public IAuthenticationInformationBuilderWithType WithType(AuthenticationInformationType value) {
        this.Type = value;
        return this;
    }

    public IAuthenticationInformationBuilderWithVersion WithVersion(string value) {
        this.Version = value;
        return this;
    }

    public AuthenticationInformation Build() {
        if (Type == null)
            throw new ArgumentNullException(nameof(Type));

        if (Content == null)
            throw new ArgumentNullException(nameof(Content));

        if (Version == null)
            throw new ArgumentNullException(nameof(Version));

        return new AuthenticationInformation(Content, Type.Value, Version);
    }
}
