#nullable enable
using Newtonsoft.Json;

namespace FitConnect.Models.Api.Metadata;

/// <summary>
/// Eine Struktur, die einen Identifikationsnachweis beschreibt.
/// </summary>
public class AuthenticationInformation {
    /// <summary>
    /// 
    /// </summary>
    /// <param name="content">Base64 URL encoded string</param>
    /// <param name="type"></param>
    /// <param name="version"></param>
    public AuthenticationInformation(string content,
        AuthenticationInformationType type, string version) {
        Content = content;
        Type = type;
        Version = version;
    }

    /// <summary>
    /// Der Nachweis wird als Base64Url-kodierte Zeichenkette angegeben.
    /// </summary>
    [JsonProperty("content")]
    public string Content { get; set; }

    /// <summary>
    /// Definiert die Art des Identifikationsnachweises.
    /// </summary>
    [JsonProperty("type")]
    public AuthenticationInformationType Type { get; set; }

    /// <summary>
    /// semver kompatible Versionsangabe des genutzten Nachweistyps.
    /// </summary>
    [JsonProperty("version")]
    public string Version { get; set; }
}
