using FitConnect.Exceptions;
using FitConnect.Validation;
using FluentAssertions;
using Microsoft.Extensions.Logging;
using Moq;

namespace ValidationTests;

public class SchemaDataSchemaBufferTests {
    private const string SCHEMA_URL =
        "https://git.fitko.de/fit-connect/sdk-dotnet/-/raw/main/Examples/example.schema.json";

    private string _schemaDataPath;
    private SchemaValidationVisitor _schemaValidationVisitor;

    public SchemaDataSchemaBufferTests() {
        _schemaDataPath = Path.Combine(Directory.GetCurrentDirectory(), "SchemaData");
        _schemaValidationVisitor = new SchemaValidationVisitor(
            _schemaDataPath,
            logger: new Mock<ILogger<SchemaValidationVisitor>>().Object);
    }

    [Fact]
    public async Task DownloadSchema() {
        var (schema, type) = await _schemaValidationVisitor.GetSchemaContent(SCHEMA_URL);
        schema.Should().NotBeNullOrEmpty();
        schema.Length.Should().BeGreaterThan(100);
    }

    [Fact]
    public void MissingSchemaCausesException() {
        var exception = Assert.Throws<AggregateException>(() => {
            var (schema, type) = _schemaValidationVisitor
                .GetSchemaContent("https://git.fitko.de/fit-connect/sdk-dotnet/-/raw/main/Examples/missing.schema.json")
                .Result;
            schema.Should().BeNullOrEmpty();
        });

        exception.InnerExceptions.First().Message.Should().Be("Data validation failed: Missing Schema");
    }
}
